@@ -71,7 +71,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 function removesnapshots ($passwd, $clientdir, $snapshot) {
 global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 
-    $cmd = sprintf ("ssh %s %s@%s 'rdiff-backup --force --remove-older-than %s %s'", 
+    $cmd = sprintf ("ssh %s %s@%s 'rdiff-backup --force --remove-older-than %s \"%s\"'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $snapshot, $clientdir) ; 
 
@@ -98,7 +98,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 function listsnapshots ($passwd, $clientdir) {
 global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 
-    $cmd = sprintf ("ssh %s %s@%s 'find %s/rdiff-backup-data -maxdepth 1 -name \"increments.*\" -printf %s'", 
+    $cmd = sprintf ("ssh %s %s@%s 'find \"%s/rdiff-backup-data\" -maxdepth 1 -name \"increments.*\" -printf %s | sort '", 
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, '"%P\n"') ; 
 
@@ -126,7 +126,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 function fetchfile ($passwd, $clientdir, $location, $file) {
 global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 
-    $cmd = sprintf ("ssh %s %s@%s 'cat %s%s/%s'", 
+    $cmd = sprintf ("ssh %s %s@%s 'cat \"%s%s/%s\"'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $file ) ; 
 
@@ -169,7 +169,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
     } else unset ($tempfile) ; 
     if (empty($tempfile))
         return ; 
-    $cmd = sprintf ("ssh %s %s@%s 'rdiff-backup --force %s/rdiff-backup-data/increments%s/%s %s'", 
+    $cmd = sprintf ("ssh %s %s@%s 'rdiff-backup --force \"%s/rdiff-backup-data/increments%s/%s %s\"'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $file, $tempfile ) ; 
 
@@ -180,7 +180,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 	fclose ($pipes[1]) ; 
 	proc_close ($proc) ; 
     } 
-    $cmd = sprintf ("ssh %s %s@%s 'cat %s && rm %s'", 
+    $cmd = sprintf ("ssh %s %s@%s 'cat \"%s\" && rm \"%s\"'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $tempfile, $tempfile) ; 
     $proc = proc_open ($cmd, $desc, $pipes, '/tmp', $env) ; 
@@ -213,7 +213,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 
     $env = array ('SSH_ASKPASS' => $ssh_askpass, 
 		  'DISPLAY' => ':nowhere') ; 
-    $cmd = sprintf ("ssh %s %s@%s 'find %s%s/%s -maxdepth 1 -mindepth 1 -type f -name %s'", 
+    $cmd = sprintf ("ssh %s %s@%s 'find \"%s%s/%s\" -maxdepth 1 -mindepth 1 -type f -name \"%s\"'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $parent, $base ) ; 
     $proc = proc_open ($cmd, $desc, $pipes, '/tmp', $env) ; 
@@ -230,7 +230,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 	proc_close ($proc) ; 
     }
     $baselen= strlen ($base) ; 
-    $cmd = sprintf ("ssh %s %s@%s 'find %s/rdiff-backup-data/increments%s/%s -maxdepth 1 -mindepth 1 -type f -name \"%s*.gz\"'", 
+    $cmd = sprintf ("ssh %s %s@%s 'find \"%s/rdiff-backup-data/increments%s/%s\" -maxdepth 1 -mindepth 1 -type f -name \"%s*.gz\"'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $parent, $base ) ; 
 
@@ -283,7 +283,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 
     $env = array ('SSH_ASKPASS' => $ssh_askpass, 
 		  'DISPLAY' => ':nowhere') ; 
-    $cmd = sprintf ("ssh %s %s@%s 'find %s%s/%s -maxdepth 1 -mindepth 1 -type d'", 
+    $cmd = sprintf ("ssh %s %s@%s 'find \"%s%s/%s\" -maxdepth 1 -mindepth 1 -type d'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $sub ) ; 
     $proc = proc_open ($cmd, $desc, $pipes, '/tmp', $env) ; 
@@ -299,7 +299,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 	fclose ($pipes[1]) ; 
 	proc_close ($proc) ; 
     }
-    $cmd = sprintf ("ssh %s %s@%s 'find %s/rdiff-backup-data/increments%s/%s -maxdepth 1 -mindepth 1 -type d'", 
+    $cmd = sprintf ("ssh %s %s@%s 'find \"%s/rdiff-backup-data/increments%s/%s\" -maxdepth 1 -mindepth 1 -type d'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $sub ) ; 
     $proc = proc_open ($cmd, $desc, $pipes, '/tmp', $env) ; 
@@ -322,7 +322,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 	fclose ($pipes[1]) ; 
 	proc_close ($proc) ; 
     }
-    $cmd = sprintf ("ssh %s %s@%s 'find %s%s/%s -maxdepth 1 -mindepth 1 -type f'", 
+    $cmd = sprintf ("ssh %s %s@%s 'find \"%s%s/%s\" -maxdepth 1 -mindepth 1 -type f'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $sub ) ; 
 
@@ -339,7 +339,7 @@ global $backuphost, $backupuser, $ssh_options, $ssh_askpass ;
 	fclose ($pipes[1]) ; 
 	proc_close ($proc) ; 
     }
-    $cmd = sprintf ("ssh %s %s@%s 'find %s/rdiff-backup-data/increments%s/%s -maxdepth 1 -mindepth 1 -type f -name \"*.snapshot.gz\"'", 
+    $cmd = sprintf ("ssh %s %s@%s 'find \"%s/rdiff-backup-data/increments%s/%s\" -maxdepth 1 -mindepth 1 -type f -name \"*.snapshot.gz\"'",
    		     $ssh_options, $backupuser, 
 		     $backuphost, $clientdir, $location, $sub ) ; 
     $proc = proc_open ($cmd, $desc, $pipes, '/tmp', $env) ; 
@@ -406,6 +406,8 @@ global $backuphost, $backupuser, $backupcron, $ssh_options, $ssh_askpass ;
 
     $env = array ('SSH_ASKPASS' => $ssh_askpass, 
 		  'DISPLAY' => ':nowhere') ; 
+
+    // cat crontab file on remote backup server
     $proc = proc_open ($cmd, $desc, $pipes, '/tmp', $env) ; 
     if (is_resource ($proc)) {
 	fprintf ($pipes[0], "%s\n", $passwd) ; 
@@ -414,6 +416,19 @@ global $backuphost, $backupuser, $backupcron, $ssh_options, $ssh_askpass ;
 	fclose ($pipes[0]) ; 
 	proc_close ($proc) ; 
 	}
+
+    // chmod on the remote backup job file
+    $cmd = sprintf ("ssh %s %s@%s 'chmod 0644 %s'",
+		     $ssh_options, $backupuser,
+		     $backuphost, $backupcron) ;
+    $proc = proc_open ($cmd, $desc, $pipes, '/tmp', $env) ;
+    if (is_resource ($proc)) {
+	fprintf ($pipes[0], "%s\n", $passwd) ;
+	fclose ($pipes[1]) ;
+	fclose ($pipes[0]) ;
+	proc_close ($proc) ;
+	}
+
 }
 
 
@@ -568,36 +583,50 @@ global $backuphost, $backupuser, $logfile, $ssh_options, $ssh_askpass ;
 
 require_once ('functions.php') ; 
 loadConfig () ;
-require('/usr/share/php/smarty/libs/Smarty.class.php') ; 
+require('/usr/share/php/smarty3/Smarty.class.php') ; 
 session_start() ;
-$authenticated = ($_COOKIE['Authenticated'] == "True") ;
 loadLocale () ; 
 ob_start ();
 
 $smarty = new Smarty();
 $smarty->template_dir = $smarty_templ ; 
 $smarty->compile_dir = $smarty_compile ; 
+unset ($_COOKIE['smarty_templ']);
+unset ($_COOKIE['smarty_compile']);
 
 # fetch script to use whith passing the ssh-password
 $ssh_askpass = sprintf ("%s/script/mypass.sh", 
                         dirname (dirname ($_SERVER["SCRIPT_FILENAME"])));
 
+$arguments = $_REQUEST;
+
+# merge _COOKIE and _REQUEST
+$allowed_cookie_keys = array('nonhttps', 'xorstring', 'PHPSESSID', 'locale',);
+foreach ($_COOKIE as $key => $value) {
+    if ((! array_key_exists($key, $arguments)) && (in_array($key, $allowed_cookie_keys))) {
+	if (is_string($key) && is_string($value)) {
+	    $arguments[$key] = $value;
+	}
+    }
+}
 
 # Fetch arguments passed as the script is executed
-foreach ($_REQUEST as $key => $value) {
+foreach ($arguments as $key => $value) {
     switch ($key) {
         case "smarty_templ": 
         case "smarty_compile": 
         case "locale": 
         case "PHPSESSID": 
             break ;
+        case "nonhttps":
+            $nonhttps = $value ;
         case "Passwd": 
             $passwd = $value ; 
             $submit = "status" ; 
             break ; 
         case "xorstring": 
             if (empty($passwd))
-		$xorstring = $value ; 
+		$xorstring = base64_decode($value) ; 
             else break ; 
             if (empty ($value))
                 break ; 
@@ -640,6 +669,8 @@ foreach ($_REQUEST as $key => $value) {
     }
 }
 
+unset ($arguments);
+
 if ($submit == "logout") {
     unset ($passwd) ; 
     unset ($xorstring) ; 
@@ -666,7 +697,7 @@ if (empty($encrypt) || empty ($xorstring)) {
     $xorstring = xorstring ($encrypt, $passwd) ; 
 }
 
-setcookie ('xorstring', $xorstring) ; 
+setcookie ('xorstring', base64_encode($xorstring)) ; 
 
 $scheduler = readcron ($passwd) ; 
 
